@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -22,7 +24,7 @@ class CodeDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CodePosition: 二维码在图片中的位置，由边界点的坐标表示
         :type CodePosition: list of CodePosition
         :param CodeCharset: 二维码文本的编码格式
@@ -48,6 +50,13 @@ class CodeDetail(AbstractModel):
         self.CodeCharset = params.get("CodeCharset")
         self.CodeText = params.get("CodeText")
         self.CodeType = params.get("CodeType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CodeDetect(AbstractModel):
@@ -56,7 +65,7 @@ class CodeDetect(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ModerationDetail: 从图片中检测到的二维码，可能为多个
         :type ModerationDetail: list of CodeDetail
         :param ModerationCode: 检测是否成功，0：成功，-1：出错
@@ -74,6 +83,13 @@ class CodeDetect(AbstractModel):
                 obj._deserialize(item)
                 self.ModerationDetail.append(obj)
         self.ModerationCode = params.get("ModerationCode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CodePosition(AbstractModel):
@@ -82,7 +98,7 @@ class CodePosition(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FloatX: 二维码边界点X轴坐标
         :type FloatX: float
         :param FloatY: 二维码边界点Y轴坐标
@@ -95,6 +111,13 @@ class CodePosition(AbstractModel):
     def _deserialize(self, params):
         self.FloatX = params.get("FloatX")
         self.FloatY = params.get("FloatY")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Coordinate(AbstractModel):
@@ -103,7 +126,7 @@ class Coordinate(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Cx: 左上角横坐标
         :type Cx: int
         :param Cy: 左上角纵坐标
@@ -124,6 +147,13 @@ class Coordinate(AbstractModel):
         self.Cy = params.get("Cy")
         self.Height = params.get("Height")
         self.Width = params.get("Width")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateFileSampleRequest(AbstractModel):
@@ -132,7 +162,7 @@ class CreateFileSampleRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Contents: 文件类型结构数组
         :type Contents: list of FileSample
         :param EvilType: 恶意类型
@@ -167,6 +197,13 @@ class CreateFileSampleRequest(AbstractModel):
         self.EvilType = params.get("EvilType")
         self.FileType = params.get("FileType")
         self.Label = params.get("Label")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateFileSampleResponse(AbstractModel):
@@ -175,7 +212,7 @@ class CreateFileSampleResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Progress: 任务状态
 1：已完成
 2：处理中
@@ -198,7 +235,7 @@ class CreateTextSampleRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Contents: 关键词数组
         :type Contents: list of str
         :param EvilType: 恶意类型
@@ -228,6 +265,13 @@ class CreateTextSampleRequest(AbstractModel):
         self.EvilType = params.get("EvilType")
         self.Label = params.get("Label")
         self.Test = params.get("Test")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateTextSampleResponse(AbstractModel):
@@ -236,7 +280,7 @@ class CreateTextSampleResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ErrMsg: 操作样本失败时返回的错误信息示例：  "样本1":错误码，"样本2":错误码
         :type ErrMsg: str
         :param Progress: 任务状态
@@ -263,7 +307,7 @@ class CustomResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Keywords: 命中的自定义关键词
         :type Keywords: list of str
         :param LibId: 自定义库id
@@ -284,6 +328,13 @@ class CustomResult(AbstractModel):
         self.LibId = params.get("LibId")
         self.LibName = params.get("LibName")
         self.Type = params.get("Type")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteFileSampleRequest(AbstractModel):
@@ -292,7 +343,7 @@ class DeleteFileSampleRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Ids: 唯一标识数组
         :type Ids: list of str
         """
@@ -301,6 +352,13 @@ class DeleteFileSampleRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.Ids = params.get("Ids")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteFileSampleResponse(AbstractModel):
@@ -309,7 +367,7 @@ class DeleteFileSampleResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Progress: 任务状态
 1：已完成
 2：处理中
@@ -332,7 +390,7 @@ class DeleteTextSampleRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Ids: 唯一标识数组，目前暂时只支持单个删除
         :type Ids: list of str
         """
@@ -341,6 +399,13 @@ class DeleteTextSampleRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.Ids = params.get("Ids")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteTextSampleResponse(AbstractModel):
@@ -349,7 +414,7 @@ class DeleteTextSampleResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Progress: 任务状态
 1：已完成
 2：处理中
@@ -372,7 +437,7 @@ class DescribeFileSampleRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Filters: 支持通过标签值进行筛选
         :type Filters: list of Filter
         :param Limit: 数量限制，默认为20，最大值为100
@@ -402,6 +467,13 @@ class DescribeFileSampleRequest(AbstractModel):
         self.Offset = params.get("Offset")
         self.OrderDirection = params.get("OrderDirection")
         self.OrderField = params.get("OrderField")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeFileSampleResponse(AbstractModel):
@@ -410,7 +482,7 @@ class DescribeFileSampleResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FileSampleSet: 符合要求的样本的信息
         :type FileSampleSet: list of FileSampleInfo
         :param TotalCount: 符合要求的样本的数量
@@ -440,7 +512,7 @@ class DescribeTextSampleRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Filters: 支持通过标签值进行筛选
         :type Filters: list of Filter
         :param Limit: 数量限制，默认为20，最大值为100
@@ -470,6 +542,13 @@ class DescribeTextSampleRequest(AbstractModel):
         self.Offset = params.get("Offset")
         self.OrderDirection = params.get("OrderDirection")
         self.OrderField = params.get("OrderField")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeTextSampleResponse(AbstractModel):
@@ -478,7 +557,7 @@ class DescribeTextSampleResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TextSampleSet: 符合要求的样本的信息
         :type TextSampleSet: list of TextSample
         :param TotalCount: 符合要求的样本的数量
@@ -508,7 +587,7 @@ class DetailResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvilLabel: 恶意标签，Normal：正常，Polity：涉政，Porn：色情，Illegal：违法，Abuse：谩骂，Terror：暴恐，Ad：广告，Custom：自定义关键词
         :type EvilLabel: str
         :param EvilType: 恶意类型
@@ -536,6 +615,13 @@ class DetailResult(AbstractModel):
         self.EvilType = params.get("EvilType")
         self.Keywords = params.get("Keywords")
         self.Score = params.get("Score")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Device(AbstractModel):
@@ -544,7 +630,7 @@ class Device(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DeviceId: 设备指纹ID
         :type DeviceId: str
         :param IDFA: IOS设备，Identifier For Advertising（广告标识符）
@@ -577,6 +663,13 @@ class Device(AbstractModel):
         self.IP = params.get("IP")
         self.Mac = params.get("Mac")
         self.TokenId = params.get("TokenId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class FileSample(AbstractModel):
@@ -585,7 +678,7 @@ class FileSample(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FileMd5: 文件md5
         :type FileMd5: str
         :param FileName: 文件名称
@@ -606,6 +699,13 @@ class FileSample(AbstractModel):
         self.FileName = params.get("FileName")
         self.FileUrl = params.get("FileUrl")
         self.CompressFileUrl = params.get("CompressFileUrl")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class FileSampleInfo(AbstractModel):
@@ -614,7 +714,7 @@ class FileSampleInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Code: 处理错误码
         :type Code: int
         :param CreatedAt: 创建时间戳
@@ -677,6 +777,13 @@ class FileSampleInfo(AbstractModel):
         self.Status = params.get("Status")
         self.CompressFileUrl = params.get("CompressFileUrl")
         self.FileUrl = params.get("FileUrl")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Filter(AbstractModel):
@@ -685,7 +792,7 @@ class Filter(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Name: 需要过滤的字段
         :type Name: str
         :param Value: 需要过滤字段的值
@@ -698,6 +805,13 @@ class Filter(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Value = params.get("Value")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageData(AbstractModel):
@@ -706,7 +820,7 @@ class ImageData(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvilFlag: 是否恶意 0：正常 1：可疑
         :type EvilFlag: int
         :param EvilType: 恶意类型
@@ -786,6 +900,13 @@ class ImageData(AbstractModel):
         if params.get("TerrorDetect") is not None:
             self.TerrorDetect = ImageTerrorDetect()
             self.TerrorDetect._deserialize(params.get("TerrorDetect"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageHotDetect(AbstractModel):
@@ -794,7 +915,7 @@ class ImageHotDetect(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvilType: 恶意类型
 100：正常
 20103：性感
@@ -821,6 +942,13 @@ class ImageHotDetect(AbstractModel):
         self.Keywords = params.get("Keywords")
         self.Labels = params.get("Labels")
         self.Score = params.get("Score")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageIllegalDetect(AbstractModel):
@@ -829,7 +957,7 @@ class ImageIllegalDetect(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvilType: 恶意类型
 100：正常 
 20006：涉毒违法
@@ -856,6 +984,13 @@ class ImageIllegalDetect(AbstractModel):
         self.Keywords = params.get("Keywords")
         self.Labels = params.get("Labels")
         self.Score = params.get("Score")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageModerationRequest(AbstractModel):
@@ -864,7 +999,7 @@ class ImageModerationRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FileContent: 文件内容 Base64,与FileUrl必须二填一
         :type FileContent: str
         :param FileMD5: 文件MD5值
@@ -881,6 +1016,13 @@ class ImageModerationRequest(AbstractModel):
         self.FileContent = params.get("FileContent")
         self.FileMD5 = params.get("FileMD5")
         self.FileUrl = params.get("FileUrl")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageModerationResponse(AbstractModel):
@@ -889,7 +1031,7 @@ class ImageModerationResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 识别结果
         :type Data: :class:`tencentcloud.cms.v20190321.models.ImageData`
         :param BusinessCode: 业务返回码
@@ -916,7 +1058,7 @@ class ImagePolityDetect(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvilType: 恶意类型
 100：正常 
 20001：政治
@@ -956,6 +1098,13 @@ class ImagePolityDetect(AbstractModel):
         self.Keywords = params.get("Keywords")
         self.PolityItems = params.get("PolityItems")
         self.Score = params.get("Score")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImagePornDetect(AbstractModel):
@@ -964,7 +1113,7 @@ class ImagePornDetect(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvilType: 恶意类型
 100：正常
 20002：色情
@@ -991,6 +1140,13 @@ class ImagePornDetect(AbstractModel):
         self.Keywords = params.get("Keywords")
         self.Labels = params.get("Labels")
         self.Score = params.get("Score")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageTerrorDetect(AbstractModel):
@@ -999,7 +1155,7 @@ class ImageTerrorDetect(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvilType: 恶意类型
 100：正常
 24001：暴恐
@@ -1026,6 +1182,13 @@ class ImageTerrorDetect(AbstractModel):
         self.Keywords = params.get("Keywords")
         self.Labels = params.get("Labels")
         self.Score = params.get("Score")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Logo(AbstractModel):
@@ -1034,7 +1197,7 @@ class Logo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RrectF: logo图标坐标信息
         :type RrectF: :class:`tencentcloud.cms.v20190321.models.RrectF`
         :param Confidence: logo图标置信度
@@ -1053,6 +1216,13 @@ class Logo(AbstractModel):
             self.RrectF._deserialize(params.get("RrectF"))
         self.Confidence = params.get("Confidence")
         self.Name = params.get("Name")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class LogoDetail(AbstractModel):
@@ -1061,7 +1231,7 @@ class LogoDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AppLogoDetail: 命中的Applogo详情
         :type AppLogoDetail: list of Logo
         """
@@ -1075,6 +1245,13 @@ class LogoDetail(AbstractModel):
                 obj = Logo()
                 obj._deserialize(item)
                 self.AppLogoDetail.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ManualReviewContent(AbstractModel):
@@ -1083,7 +1260,7 @@ class ManualReviewContent(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BatchId: 审核批次号
         :type BatchId: str
         :param Content: 审核内容
@@ -1142,6 +1319,13 @@ class ManualReviewContent(AbstractModel):
         self.CreateTime = params.get("CreateTime")
         self.Priority = params.get("Priority")
         self.Title = params.get("Title")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ManualReviewData(AbstractModel):
@@ -1150,7 +1334,7 @@ class ManualReviewData(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BatchId: 人审内容批次号
         :type BatchId: str
         :param ContentId: 人审内容ID
@@ -1163,6 +1347,13 @@ class ManualReviewData(AbstractModel):
     def _deserialize(self, params):
         self.BatchId = params.get("BatchId")
         self.ContentId = params.get("ContentId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ManualReviewRequest(AbstractModel):
@@ -1171,7 +1362,7 @@ class ManualReviewRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ReviewContent: 人工审核信息
         :type ReviewContent: :class:`tencentcloud.cms.v20190321.models.ManualReviewContent`
         """
@@ -1182,6 +1373,13 @@ class ManualReviewRequest(AbstractModel):
         if params.get("ReviewContent") is not None:
             self.ReviewContent = ManualReviewContent()
             self.ReviewContent._deserialize(params.get("ReviewContent"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ManualReviewResponse(AbstractModel):
@@ -1190,7 +1388,7 @@ class ManualReviewResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 人审接口同步响应结果
         :type Data: :class:`tencentcloud.cms.v20190321.models.ManualReviewData`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1213,7 +1411,7 @@ class OCRDetect(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Item: 识别到的详细信息
         :type Item: list of OCRItem
         :param TextInfo: 识别到的文本信息
@@ -1231,6 +1429,13 @@ class OCRDetect(AbstractModel):
                 obj._deserialize(item)
                 self.Item.append(obj)
         self.TextInfo = params.get("TextInfo")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OCRItem(AbstractModel):
@@ -1239,7 +1444,7 @@ class OCRItem(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TextPosition: 检测到的文本坐标信息
         :type TextPosition: :class:`tencentcloud.cms.v20190321.models.Coordinate`
         :param EvilLabel: 文本命中具体标签
@@ -1270,6 +1475,13 @@ class OCRItem(AbstractModel):
         self.Keywords = params.get("Keywords")
         self.Rate = params.get("Rate")
         self.TextContent = params.get("TextContent")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class PhoneDetect(AbstractModel):
@@ -1278,7 +1490,7 @@ class PhoneDetect(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvilType: 恶意类型
 100：正常
 21000：综合
@@ -1301,6 +1513,13 @@ class PhoneDetect(AbstractModel):
         self.HitFlag = params.get("HitFlag")
         self.Labels = params.get("Labels")
         self.Score = params.get("Score")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RiskDetails(AbstractModel):
@@ -1309,7 +1528,7 @@ class RiskDetails(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Keywords: 预留字段，暂时不使用
         :type Keywords: list of str
         :param Label: 风险类别，RiskAccount，RiskIP, RiskIMEI
@@ -1330,6 +1549,13 @@ class RiskDetails(AbstractModel):
         self.Label = params.get("Label")
         self.Lable = params.get("Lable")
         self.Level = params.get("Level")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RrectF(AbstractModel):
@@ -1338,7 +1564,7 @@ class RrectF(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Cx: logo横坐标
         :type Cx: float
         :param Cy: logo纵坐标
@@ -1363,6 +1589,13 @@ class RrectF(AbstractModel):
         self.Height = params.get("Height")
         self.Rotate = params.get("Rotate")
         self.Width = params.get("Width")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Similar(AbstractModel):
@@ -1371,7 +1604,7 @@ class Similar(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvilType: 恶意类型
 100：正常 
 20001：政治
@@ -1394,6 +1627,13 @@ class Similar(AbstractModel):
         self.EvilType = params.get("EvilType")
         self.HitFlag = params.get("HitFlag")
         self.SeedUrl = params.get("SeedUrl")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TextData(AbstractModel):
@@ -1402,7 +1642,7 @@ class TextData(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param EvilFlag: 是否恶意 0：正常 1：可疑
         :type EvilFlag: int
         :param EvilType: 恶意类型
@@ -1495,6 +1735,13 @@ class TextData(AbstractModel):
         self.Keywords = params.get("Keywords")
         self.Score = params.get("Score")
         self.Suggestion = params.get("Suggestion")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TextModerationRequest(AbstractModel):
@@ -1503,7 +1750,7 @@ class TextModerationRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Content: 文本内容Base64编码。原文长度需小于15000字节，即5000个汉字以内。
         :type Content: str
         :param Device: 设备相关信息
@@ -1536,6 +1783,13 @@ class TextModerationRequest(AbstractModel):
         self.BizType = params.get("BizType")
         self.DataId = params.get("DataId")
         self.SdkAppId = params.get("SdkAppId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TextModerationResponse(AbstractModel):
@@ -1544,7 +1798,7 @@ class TextModerationResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 识别结果
         :type Data: :class:`tencentcloud.cms.v20190321.models.TextData`
         :param BusinessCode: 业务返回码
@@ -1571,7 +1825,7 @@ class TextOutputComm(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AppID: 接入业务的唯一ID
         :type AppID: int
         :param BUCtrlID: 接口唯一ID，旁路调用接口返回有该字段，标识唯一接口
@@ -1592,6 +1846,13 @@ class TextOutputComm(AbstractModel):
         self.BUCtrlID = params.get("BUCtrlID")
         self.SendTime = params.get("SendTime")
         self.Uin = params.get("Uin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TextOutputID(AbstractModel):
@@ -1600,7 +1861,7 @@ class TextOutputID(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param MsgID: 接入业务的唯一ID
         :type MsgID: str
         :param Uin: 用户账号uin，对应请求协议里的Content.User.Uin。旁路结果有回带，串联结果无该字段
@@ -1613,6 +1874,13 @@ class TextOutputID(AbstractModel):
     def _deserialize(self, params):
         self.MsgID = params.get("MsgID")
         self.Uin = params.get("Uin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TextOutputRes(AbstractModel):
@@ -1621,7 +1889,7 @@ class TextOutputRes(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Operator: 操作人,信安处理人企业微信ID
         :type Operator: str
         :param ResultCode: 恶意操作码，
@@ -1643,6 +1911,13 @@ class TextOutputRes(AbstractModel):
         self.ResultCode = params.get("ResultCode")
         self.ResultMsg = params.get("ResultMsg")
         self.ResultType = params.get("ResultType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TextSample(AbstractModel):
@@ -1651,7 +1926,7 @@ class TextSample(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Code: 处理错误码
         :type Code: int
         :param Content: 关键词
@@ -1695,6 +1970,13 @@ class TextSample(AbstractModel):
         self.Id = params.get("Id")
         self.Label = params.get("Label")
         self.Status = params.get("Status")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class User(AbstractModel):
@@ -1703,7 +1985,7 @@ class User(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AccountType: 账号类别，"1-微信uin 2-QQ号 3-微信群uin 4-qq群号 5-微信openid 6-QQopenid 7-其它string"
         :type AccountType: int
         :param Age: 年龄 默认0 未知
@@ -1735,4 +2017,11 @@ class User(AbstractModel):
         self.Level = params.get("Level")
         self.Nickname = params.get("Nickname")
         self.Phone = params.get("Phone")
-        self.UserId = params.get("UserId")
\ No newline at end of file
+        self.UserId = params.get("UserId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
