@@ -26,6 +26,9 @@ FAILEDOPERATION_CREATEACCOUNT = 'FailedOperation.CreateAccount'
 # 账号实名认证超过上限。
 FAILEDOPERATION_CREATEMEMBERAUTHOVERLIMIT = 'FailedOperation.CreateMemberAuthOverLimit'
 
+# 创建测试失败。
+FAILEDOPERATION_CREATEPOLICY = 'FailedOperation.CreatePolicy'
+
 # 创建已成功。
 FAILEDOPERATION_CREATERECORDALREADYSUCCESS = 'FailedOperation.CreateRecordAlreadySuccess'
 
@@ -38,6 +41,9 @@ FAILEDOPERATION_CREATEROLE = 'FailedOperation.CreateRole'
 # 名字已经被使用。
 FAILEDOPERATION_MEMBERNAMEUSED = 'FailedOperation.MemberNameUsed'
 
+# 成员授权策略名已存在。
+FAILEDOPERATION_MEMBERPOLICYNAMEEXIST = 'FailedOperation.MemberPolicyNameExist'
+
 # 操作计费侧成员权限错误。
 FAILEDOPERATION_OPERATEBILLINGPERMISSIONERR = 'FailedOperation.OperateBillingPermissionErr'
 
@@ -77,6 +83,9 @@ LIMITEXCEEDED_CREATEMEMBEROVERLIMIT = 'LimitExceeded.CreateMemberOverLimit'
 # 成员超过上限。
 LIMITEXCEEDED_ORGANIZATIONMEMBEROVERLIMIT = 'LimitExceeded.OrganizationMemberOverLimit'
 
+# 成员可授权身份不存在。
+RESOURCENOTFOUND_MEMBERIDENTITYNOTEXIST = 'ResourceNotFound.MemberIdentityNotExist'
+
 # 成员不存在。
 RESOURCENOTFOUND_MEMBERNOTEXIST = 'ResourceNotFound.MemberNotExist'
 
@@ -86,6 +95,12 @@ RESOURCENOTFOUND_MEMBERPOLICYNOTEXIST = 'ResourceNotFound.MemberPolicyNotExist'
 # 企业组织不存在。
 RESOURCENOTFOUND_ORGANIZATIONNOTEXIST = 'ResourceNotFound.OrganizationNotExist'
 
+# 集团服务不存在。
+RESOURCENOTFOUND_ORGANIZATIONSERVICENOTEXIST = 'ResourceNotFound.OrganizationServiceNotExist'
+
+# 操作不支持。
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
 # 不允许添加代付关系。
 UNSUPPORTEDOPERATION_ADDDELEGATEPAYERNOTALLOW = 'UnsupportedOperation.AddDelegatePayerNotAllow'
 
@@ -104,6 +119,9 @@ UNSUPPORTEDOPERATION_MEMBERACCOUNTARREARS = 'UnsupportedOperation.MemberAccountA
 # 成员存在优惠继承。
 UNSUPPORTEDOPERATION_MEMBERDISCOUNTINHERITEXISTED = 'UnsupportedOperation.MemberDiscountInheritExisted'
 
+# 成员存在账户级优惠。
+UNSUPPORTEDOPERATION_MEMBEREXISTACCOUNTLEVELDISCOUNTINHERIT = 'UnsupportedOperation.MemberExistAccountLevelDiscountInherit'
+
 # 成员是代理商或代客。
 UNSUPPORTEDOPERATION_MEMBERISAGENT = 'UnsupportedOperation.MemberIsAgent'
 
@@ -115,3 +133,6 @@ UNSUPPORTEDOPERATION_OWNERDISCOUNTINHERITEXISTED = 'UnsupportedOperation.OwnerDi
 
 # 代付者欠费且未开通信用账户。
 UNSUPPORTEDOPERATION_PAYERARREARSANDNOCREDITACCOUNT = 'UnsupportedOperation.PayerArrearsAndNoCreditAccount'
+
+# 代付者存在账户级优惠。
+UNSUPPORTEDOPERATION_PAYEREXISTACCOUNTLEVELDISCOUNTINHERIT = 'UnsupportedOperation.PayerExistAccountLevelDiscountInherit'
